<?php
/**
 * Custom functions that act in the footer.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package GardenHub
 */

/**
 *  Display site footer
 */
function gardenhub_footer() {
	?>
	<div class="container">
		<div class="row">
			<div class="footer-copyright col-md-4 col-sm-12 col-sx-12">
				<div class="site-info">
					<?php echo do_shortcode( wp_kses( gardenhub_get_option( 'footer_copyright' ), wp_kses_allowed_html( 'post' ) ) ); ?>
				</div>
				<!-- .site-info -->
			</div>
			<div class="footer-socials col-md-4 col-sm-12 col-sx-12 text-center">
				<?php gardenhub_footer_social(); ?>
			</div>
			<div class="col-md-4 col-sm-12 col-xs-12 text-right footer-menu">
				<?php
				if ( has_nav_menu( 'footer' ) ) {
					wp_nav_menu(
						array(
							'theme_location' => 'footer',
						)
					);
				}
				?>
			</div>
		</div>
	</div>
	<?php
}

add_action( 'gardenhub_footer', 'gardenhub_footer' );

/**
 *  Display footer widget
 */
function gardenhub_footer_widgets() {
	if ( ! intval( gardenhub_get_option( 'footer_widget' ) ) ) {
		return false;
	}

	if ( is_active_sidebar( 'footer-sidebar-1' ) == false &&
		is_active_sidebar( 'footer-sidebar-2' ) == false &&
		is_active_sidebar( 'footer-sidebar-3' ) == false &&
		is_active_sidebar( 'footer-sidebar-4' ) == false
	) {
		return false;
	}
	?>
	<div id="footer-widgets" class="footer-widgets widgets-area">
		<div class="container">
			<div class="row">

				<?php

				$columns   = max( 1, absint( gardenhub_get_option( 'footer_widget_columns' ) ) );
				$col_class = 'col-xs-12 col-sm-6 col-md-' . floor( 12 / $columns );
				for ( $i = 1; $i <= $columns; $i ++ ) :
					?>
					<div class="footer-sidebar footer-<?php echo esc_attr( $i ) ?> <?php echo esc_attr( $col_class ) ?>">
						<?php dynamic_sidebar( "footer-sidebar-$i" ); ?>
					</div>
				<?php endfor; ?>

			</div>
		</div>
	</div>
	<?php
}

add_action( 'gardenhub_before_footer', 'gardenhub_footer_widgets' );

function gardenhub_footer_social() {

	$header_social = gardenhub_get_option( 'footer_socials' );

	?>
	<div class="socials footer-social">
		<?php

		if ( $header_social ) {

			$socials = gardenhub_get_socials();

			foreach ( $header_social as $social ) {
				foreach ( $socials as $name => $label ) {
					$link_url = $social['link_url'];

					if ( preg_match( '/' . $name . '/', $link_url ) ) {

						if ( $name == 'google' ) {
							$name = 'google-plus';
						}

						printf( '<a href="%s" target="_blank"><i class="fa fa-%s"></i></a>', esc_url( $link_url ), esc_attr( $name ) );
						break;
					}
				}
			}
		}
		?>
	</div>
	<?php
}

/**
 * Add a modal on the footer, for displaying footer modal
 *
 * @since 1.0.0
 */
function gardenhub_footer_modal() {
	?>
	<div id="modal" class="modal fade" tabindex="-1" aria-hidden="true">
		<div class="item-detail">
			<div class="modal-dialog woocommerce">
				<div class="modal-content product">
					<div class="modal-header">
						<button type="button" class="close fh-close-modal" data-dismiss="modal">&#215;<span
								class="sr-only"></span></button>
					</div>
					<div class="modal-body"></div>
				</div>
			</div>
		</div>
	</div>
	<?php
}

add_action( 'wp_footer', 'gardenhub_footer_modal' );

/**
 * Add off mobile menu to footer
 *
 * @since 1.0.0
 */
function gardenhub_off_canvas_mobile_menu() {
	$header_layout = gardenhub_get_option( 'header_layout' );

	?>
	<div class="primary-mobile-nav" id="primary-mobile-nav" role="navigation">
		<a href="#" class="close-canvas-mobile-panel">
			&#215;
		</a>
		<?php
		wp_nav_menu(
			array(
				'theme_location' => 'primary',
				'container'      => false,
			)
		);
		?>

		<?php if ( gardenhub_get_option( 'header_search' ) && in_array( $header_layout, array( 'v4', 'v2' ) ) ) :
			printf(
				'<div class="extra-item menu-item-search">
					<form method="get" class="search-form" action="%s">
						<i class="fa fa-search" aria-hidden="true"></i>
						<input type="search" class="search-field" placeholder="%s..." value="" name="s">
						<input type="submit" class="search-submit" value="Search">
					</form>
				</div>',
				esc_url( home_url( '/' ) ),
				esc_attr__( 'Search', 'gardenhub' )
			);
		endif ?>

		<?php if ( gardenhub_get_option( 'extra_text' ) && in_array( $header_layout, array( 'v3', 'v1' ) ) ) :
			printf(
				'<div class="extra-item menu-item-text">%s</div>',
				wp_kses( gardenhub_get_option( 'extra_text' ), wp_kses_allowed_html( 'post' ) )
			);
		endif ?>

	</div>
	<?php
}

add_action( 'wp_footer', 'gardenhub_off_canvas_mobile_menu' );

/**
 * Display a layer to close canvas panel everywhere inside page
 *
 * @since 1.0.0
 */
function gardenhub_site_canvas_layer() {
	?>
	<div id="off-canvas-layer" class="off-canvas-layer"></div>
	<?php
}

add_action( 'wp_footer', 'gardenhub_site_canvas_layer' );

/**
 * Display back to top
 *
 * @since 1.0.0
 */
function gardenhub_back_to_top() {
	if ( gardenhub_get_option( 'back_to_top' ) ) :
		?>
		<a id="scroll-top" class="backtotop" href="#page-top">
			<i class="fa fa-angle-up"></i>
		</a>
		<?php
	endif;
}

add_action( 'wp_footer', 'gardenhub_back_to_top' );
