<?php
/**
 * Hooks for template header
 *
 * @package GardenHub
 */

/**
 * Enqueue scripts and styles.
 *
 * @since 1.0
 */
function gardenhub_enqueue_scripts() {
	/**
	 * Register and enqueue styles
	 */
	wp_register_style( 'gardenhub-fonts', gardenhub_fonts_url(), array(), '20161025' );
	wp_register_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', array(), '3.3.7' );
	wp_register_style( 'fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), '4.6.3' );
	wp_register_style( 'factoryplus-icons', get_template_directory_uri() . '/css/factoryplus-icons.css', array(), '20161025' );
	wp_register_style( 'flaticon', get_template_directory_uri() . '/css/flaticon.css', array(), '20170425' );

	wp_enqueue_style( 'gardenhub', get_template_directory_uri() . '/style.css', array( 'gardenhub-fonts', 'factoryplus-icons', 'flaticon', 'bootstrap', 'fontawesome' ), '20161025' );

	wp_add_inline_style( 'gardenhub', gardenhub_customize_css() );

	/**
	 * Register and enqueue scripts
	 */
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_enqueue_script( 'html5shiv', get_template_directory_uri() . '/js/html5shiv.min.js', array(), '3.7.2' );
	wp_script_add_data( 'html5shiv', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'respond', get_template_directory_uri() . '/js/respond.min.js', array(), '1.4.2' );
	wp_script_add_data( 'respond', 'conditional', 'lt IE 9' );

	wp_register_script( 'imagesloaded', get_template_directory_uri() . '/js/plugins/imagesloaded.pkgd.min.js', array(), '3.1.8', true );
	wp_register_script( 'isotope', get_template_directory_uri() . '/js/plugins/isotope.pkgd.min.js', array(), '2.2.2', true );
	wp_register_script( 'tabs', get_template_directory_uri() . '/js/plugins/jquery.tabs.js', array(), '1.0', true );
	wp_register_script( 'parallax', get_template_directory_uri() . '/js/plugins/jquery.parallax.min.js', array(), '1.0', true );
	wp_register_script( 'owlcarousel', get_template_directory_uri() . '/js/plugins/owl.carousel.js', array(), '2.2.0', true );

	wp_enqueue_script( 'gardenhub', get_template_directory_uri() . "/js/scripts$min.js", array(
		'jquery',
		'imagesloaded',
		'isotope',
		'tabs',
		'parallax',
		'owlcarousel'

	), '20161025', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_localize_script(
		'gardenhub', 'gardenhub', array(
			'gardenhub_back' => esc_html__( 'Back', 'gardenhub' ),
			'direction'      => is_rtl() ? 'rtl' : '',
		)
	);
}

add_action( 'wp_enqueue_scripts', 'gardenhub_enqueue_scripts' );

/**
 * Enqueues front-end CSS for theme customization
 */
function gardenhub_customize_css() {
	$inline_style = '';

	// Logo
	$logo_size_width = intval( gardenhub_get_option( 'logo_width' ) );
	$logo_css        = $logo_size_width ? 'width:' . $logo_size_width . 'px; ' : '';

	$logo_size_height = intval( gardenhub_get_option( 'logo_height' ) );
	$logo_css .= $logo_size_height ? 'height:' . $logo_size_height . 'px; ' : '';

	$logo_margin = gardenhub_get_option( 'logo_position' );
	$logo_css .= $logo_margin['top'] ? 'margin-top:' . $logo_margin['top'] . '; ' : '';
	$logo_css .= $logo_margin['right'] ? 'margin-right:' . $logo_margin['right'] . '; ' : '';
	$logo_css .= $logo_margin['bottom'] ? 'margin-bottom:' . $logo_margin['bottom'] . '; ' : '';
	$logo_css .= $logo_margin['left'] ? 'margin-left:' . $logo_margin['left'] . '; ' : '';

	if ( ! empty( $logo_css ) ) {
		$inline_style .= '.site-header .logo img ' . ' {' . $logo_css . '}';
	}

	// Topbar background color
	$topbar_bg_color = gardenhub_get_option( 'topbar_bg_color' );
	if ( $topbar_bg_color ) {
		$inline_style .= '.topbar { background-color: ' . $topbar_bg_color . '; }';
	}

	// Page header image
	if ( $image = gardenhub_get_page_header_image() ) {
		$inline_style .= '.header-title { background-image: url(' . esc_url( $image ) . '); }';
	}

	// Footer Background
	$footer_image          = gardenhub_get_option( 'footer_widget_bg' );
	$footer_bg_color       = gardenhub_get_option( 'footer_bg_color' );
	$footerwidget_bg_color = gardenhub_get_option( 'footer_widget_bg_color' );

	$footer_bg_color = str_replace( '#', '', $footer_bg_color );
	$footer_bg_color = '#' . $footer_bg_color;

	$footer_css = ! empty( $footer_bg_color ) ? "background-color: {$footer_bg_color};" : '';
	$inline_style .= '.site-footer {' . $footer_css . '}';

	$footerwidget_bg_color = str_replace( '#', '', $footerwidget_bg_color );
	$footerwidget_bg_color = '#' . $footerwidget_bg_color;

	$footerwidget_css = ! empty( $footerwidget_bg_color ) ? "background-color: {$footerwidget_bg_color};" : '';
	if ( ! empty( $footer_image ) ) {
		$footerwidget_css .= "background-image: url({$footer_image});";
	}
	$inline_style .= '.footer-widgets {' . $footerwidget_css . '}';

	/* 404 background */

	if ( is_404() ) {
		$banner = gardenhub_get_option( '404_bg' );

		if ( $banner ) {
			$inline_style .= '.error404 .site-content { background-image: url( ' . esc_url( $banner ) . '); }';
		}
	}

	$color_scheme_option = gardenhub_get_option( 'color_scheme' );

	if ( intval( gardenhub_get_option( 'custom_color_scheme' ) ) ) {
		$color_scheme_option = gardenhub_get_option( 'custom_color' );
	}

	// Don't do anything if the default color scheme is selected.
	if ( $color_scheme_option ) {
		$inline_style .= gardenhub_get_color_scheme_css( $color_scheme_option );
	}

	$inline_style .= gardenhub_typography_css();

	$inline_style .= gardenhub_get_heading_typography_css();

	return $inline_style;

}

/**
 * Display header
 */
function gardenhub_show_header() {
	get_template_part( 'parts/headers/header', gardenhub_get_option( 'header_layout' ) );
}

add_action( 'gardenhub_header', 'gardenhub_show_header' );

/**
 * Display topbar on top of site
 *
 * @since 1.0.0
 */
function gardenhub_show_topbar() {
	if ( ! gardenhub_get_option( 'topbar_enable' ) ) {
		return;
	}

	$class = 'topbar-' . gardenhub_get_option( 'topbar_style' );
	?>
	<div id="topbar" class="topbar <?php echo esc_attr( $class ) ?>">
		<div class="container">
			<div class="row">
				<?php if ( is_active_sidebar( 'topbar-left' ) ) : ?>

					<div class="topbar-left topbar-widgets text-left col-md-7 col-sm-12 col-xs-12">
						<?php
						ob_start();
						dynamic_sidebar( 'topbar-left' );
						$output = ob_get_clean();

						echo apply_filters( 'gardenhub_topbar_left', $output );
						?>
					</div>

				<?php endif; ?>
				<?php if ( is_active_sidebar( 'topbar-right' ) ) : ?>

					<div class="topbar-right topbar-widgets text-right col-md-5 col-sm-12 col-xs-12">
						<?php
						ob_start();
						dynamic_sidebar( 'topbar-right' );
						$output = ob_get_clean();

						echo apply_filters( 'gardenhub_topbar_right', $output );
						?>
					</div>

				<?php endif; ?>
			</div>
		</div>
	</div>
	<?php
}

add_action( 'gardenhub_before_header', 'gardenhub_show_topbar' );

/**
 * Display page header
 */
function gardenhub_page_header() {
	if ( ! gardenhub_has_page_header() ) {
		return;
	}

	if ( intval( get_post_meta( get_the_ID(), 'custom_page_header_layout', true ) ) ) {
		$layout = intval( get_post_meta( get_the_ID(), 'page_header_layout', true ) );

		get_template_part( 'parts/page-headers/page-header', $layout );

	} else {
		get_template_part( 'parts/page-headers/page-header-1' );
	}
}

add_action( 'gardenhub_after_header', 'gardenhub_page_header' );

/**
 * Display the main breadcrumb
 */
function gardenhub_site_breadcrumb() {

	if ( ! intval( gardenhub_get_option( 'show_breadcrumb' ) ) ) {
		return;
	}

	if ( is_singular() && get_post_meta( get_the_ID(), 'hide_breadcrumb', true ) ) {
		return;
	}

	$args = array(
		'delimiter' => '<i class="fa fa-angle-right" aria-hidden="true"></i>',
	);

	if ( function_exists( 'is_woocommerce' ) && is_woocommerce() && function_exists( 'woocommerce_breadcrumb' ) ) {
		woocommerce_breadcrumb( $args );
	} else {
		gardenhub_breadcrumbs();
	}
}

/**
 * Filter to archive title and add page title for singular pages
 *
 * @param string $title
 *
 * @return string
 */
function gardenhub_the_archive_title( $title ) {
	if ( is_search() ) {
		$title = sprintf( esc_html__( 'Search Results', 'gardenhub' ) );
	} elseif ( is_404() ) {
		$title = sprintf( esc_html__( 'Page Not Found', 'gardenhub' ) );
	} elseif ( is_page() ) {
		$title = get_the_title();
	} elseif ( is_home() && is_front_page() ) {
		$title = esc_html__( 'The Latest Posts', 'gardenhub' );
	} elseif ( is_home() && ! is_front_page() ) {
		$title = get_the_title( get_option( 'page_for_posts' ) );
	} elseif ( function_exists( 'is_shop' ) && is_shop() ) {
		$title = get_the_title( get_option( 'woocommerce_shop_page_id' ) );
	} elseif ( function_exists( 'is_product' ) && is_product() ) {
		$title = get_the_title();
	} elseif ( is_single() ) {
		$title = get_the_title();
	} elseif ( is_post_type_archive( 'project' ) ) {
		$portfolio_page_id = get_option( 'sth_project_page_id' );

		if ( $portfolio_page_id && get_post( $portfolio_page_id ) ) {
			$title = get_the_title( $portfolio_page_id );
		} else {
			$title = _x( 'Project', 'Project post type title', 'gardenhub' );
		}

	} elseif ( is_post_type_archive( 'service' ) ) {
		$service_page_id = get_option( 'sth_service_page_id' );

		if ( $service_page_id && get_post( $service_page_id ) ) {
			$title = get_the_title( $service_page_id );
		} else {
			$title = _x( 'Service', 'Service post type title', 'gardenhub' );
		}

	} elseif ( is_post_type_archive( 'testimonial' ) ) {
		$testimonial_page_id = get_option( 'sth_testimonial_page_id' );

		if ( $testimonial_page_id && get_post( $testimonial_page_id ) ) {
			$title = get_the_title( $testimonial_page_id );
		} else {
			$title = _x( 'Testimonial', 'Testimonial post type title', 'gardenhub' );
		}

	} elseif ( is_tax() ) {
		$title = single_term_title( '', false );
	}

	return $title;
}

add_filter( 'get_the_archive_title', 'gardenhub_the_archive_title' );

/**
 * Display the header minimized
 *
 * @since 1.0.0
 */
function gardenhub_header_minimized() {

	if ( ! intval( gardenhub_get_option( 'header_sticky' ) ) ) {
		return;
	}

	if ( gardenhub_get_option( 'header_layout' ) == 'v3' ) {
		return;
	}

	$css_class = 'fh-header-' . gardenhub_get_option( 'header_layout' );

	printf( '<div id="fh-header-minimized" class="fh-header-minimized %s"></div>', esc_attr( $css_class ) );

}

add_action( 'gardenhub_before_header', 'gardenhub_header_minimized' );

/**
 * Returns CSS for the color schemes.
 *
 *
 * @param array $colors Color scheme colors.
 *
 * @return string Color scheme CSS.
 */
function gardenhub_get_color_scheme_css( $colors ) {
	return <<<CSS
	/*Background Color: */

	.fh-latest-post .item-latest-post .entry-time,
	.fh-icon-box.style-1 .fh-icon,
	.fh-icon-box-2 .item-box:hover,
	.fh-testimonials-carousel.style-4 .owl-dots .owl-dot.active span,.fh-testimonials-carousel.style-4 .owl-dots .owl-dot:hover span,
	.fh-price-table .table-header,
	.fh-price-table.promoted .table-content a,.fh-price-table:hover .table-content a,
	.fh-price-table.style-2.promoted .table-content a,.fh-price-table.style-2:hover .table-content a,
	.fh-service.style-2 .summary .fh-btn-3:hover,
	.fh-service-2.style-1 .service-content:hover .summary,
	.custom-quote.quote-project blockquote:after,
	.gh-accordion.vc_tta-accordion .vc_tta-panel.vc_active .vc_tta-panel-title a i,
	.gh-accordion.style-2.vc_tta-accordion .vc_tta-panel.vc_active .vc_tta-panel-title a i,
	.fh-service.style-2 .service-content:hover .fh-btn-3,
	.main-background-color,
	.topbar .widget .topbar-button,
	.page-header.style-2 .page-button-link a:hover,
	.header-v3.header-transparent .site-extra-text .social a:hover,
	.nav li li:hover,
	.header-v1 .menu-item-text .text-1,
	.header-v3 .menu-item-text .item-text,
	.header-v3.header-transparent .main-nav,
	.header-v3.header-transparent .main-nav ul.menu > li,
	.header-v4 .menu-item-search .toggle-search,
	.numeric-navigation .page-numbers:hover,.numeric-navigation .page-numbers.current,
	.project-nav-ajax nav.numeric-navigation .page-numbers.next:hover,.project-nav-ajax nav.numeric-navigation .page-numbers.next:focus,
	.primary-mobile-nav .menu-item-button-link a,
	.fh-btn,
	.fh-btn:hover,.fh-btn:focus,
	.post-author .box-title:after,
	.blog-grid .blog-wrapper .entry-time,
	.socials-share a,
	.single-service blockquote:before,
	.single-project .single-project-title:before,
	.all-project ul.filter li.active,.all-project ul.filter li:hover,
	.comments-title:after,.comment-reply-title:after,
	.comment-respond .form-submit .submit,
	.comment-respond .form-submit .submit:hover,.comment-respond .form-submit .submit:focus,
	.widget_tag_cloud a:hover,
	.service-sidebar .services-menu-widget ul li:hover,.service-sidebar .services-menu-widget ul li.current-menu-item,
	.service-sidebar .download .item-download:hover,
	.woocommerce .added_to_cart,.woocommerce button.button,.woocommerce a.button,.woocommerce input.button,.woocommerce #respond input#submit,
	.woocommerce .added_to_cart:hover,.woocommerce button.button:hover,.woocommerce a.button:hover,.woocommerce input.button:hover,.woocommerce #respond input#submit:hover,.woocommerce .added_to_cart:focus,.woocommerce button.button:focus,.woocommerce a.button:focus,.woocommerce input.button:focus,.woocommerce #respond input#submit:focus,
	.woocommerce .added_to_cart.alt,.woocommerce button.button.alt,.woocommerce a.button.alt,.woocommerce input.button.alt,.woocommerce #respond input#submit.alt,
	.woocommerce .added_to_cart.alt:hover,.woocommerce button.button.alt:hover,.woocommerce a.button.alt:hover,.woocommerce input.button.alt:hover,.woocommerce #respond input#submit.alt:hover,.woocommerce .added_to_cart.alt:focus,.woocommerce button.button.alt:focus,.woocommerce a.button.alt:focus,.woocommerce input.button.alt:focus,.woocommerce #respond input#submit.alt:focus,
	.woocommerce #reviews #review_form .comment-form .form-submit input.submit,
	.woocommerce form.checkout #payment div.place-order .button,
	.woocommerce .widget_price_filter .price_slider .ui-slider-handle,
	.woocommerce .widget_product_tag_cloud a:hover,
	.woocommerce nav.woocommerce-pagination ul li .page-numbers:hover,.woocommerce nav.woocommerce-pagination ul li .page-numbers.current,
	.woocommerce-cart table.cart td.actions .coupon .button,
	.woocommerce-cart table.cart td.actions .coupon .button:hover,.woocommerce-cart table.cart td.actions .coupon .button:focus,
	.woocommerce-cart .wc-proceed-to-checkout a.button,
	.woocommerce-cart .wc-proceed-to-checkout a.button:hover,.woocommerce-cart .wc-proceed-to-checkout a.button:focus,
	.woocommerce div.product div.summary button.single_add_to_cart_button.disabled,
	.footer-widgets .fh-form-field .subscribe:after,
	.tabs-widget .tabs-nav li a.active,
	.factoryplus-bullets.tp-bullets .tp-bullet.selected,
	.factoryplus-bullets.tp-bullets .tp-bullet:hover {background-color: $colors}

	.fh_button:hover, .tp-caption.fh_button:hover {background-color: $colors !important}

	/*Border Color: */

	.fh-section-title.has-icon h2:before,
	.fh-testimonials-carousel .owl-nav div:hover,
	.fh-testimonials-carousel.style-2 .owl-nav div:hover,
	.fh-testimonials-carousel.style-2 .owl-dots .owl-dot:hover span,.fh-testimonials-carousel.style-2 .owl-dots .owl-dot.active span,
	.fh-testimonials-carousel.style-3 .owl-nav div:hover,
	.fh-testimonials-carousel.style-4 .owl-dots .owl-dot.active span,.fh-testimonials-carousel.style-4 .owl-dots .owl-dot:hover span,
	.fh-price-table.promoted .table-content a,.fh-price-table:hover .table-content a,
	.fh-price-table.style-2.promoted,.fh-price-table.style-2:hover,
	.fh-price-table.style-2.promoted .table-header,.fh-price-table.style-2:hover .table-header,
	.fh-price-table.style-2.promoted .table-content a,.fh-price-table.style-2:hover .table-content a,
	.fh-service.style-2 .summary .fh-btn-3:hover,
	.fh-team.style-1 .socials-1 ul li a:hover,
	.gh-accordion.style-2.vc_tta-accordion .vc_tta-panel.vc_active .vc_tta-panel-title a i,
	.service-tabs .vc_tta-tabs-list li:hover a,.service-tabs .vc_tta-tabs-list li.vc_active a,
	.fh-service.style-2 .service-content:hover .fh-btn-3,
	.page-header.style-2 .page-button-link a:hover,
	.header-v1 .menu-item-text .header-phone,
	.header-v3.header-transparent .site-extra-text .social a:hover,
	.numeric-navigation .page-numbers:hover,.numeric-navigation .page-numbers.current,
	.project-nav-ajax nav.numeric-navigation .page-numbers.next:hover,.project-nav-ajax nav.numeric-navigation .page-numbers.next:focus,
	.service:hover .service-inner,
	.single-project .entry-thumbnail .owl-controls .owl-pagination .owl-page:hover span,.single-project .entry-thumbnail .owl-controls .owl-pagination .owl-page.active span,
	.service-sidebar .services-menu-widget ul li:hover,.service-sidebar .services-menu-widget ul li.current-menu-item,
	.service-sidebar .download .item-download:hover,
	.woocommerce ul.products li.product .product-inner:hover,
	.woocommerce nav.woocommerce-pagination ul li .page-numbers:hover,.woocommerce nav.woocommerce-pagination ul li .page-numbers.current,
	.backtotop,
	.factoryplus-arrow:hover,
	.factoryplus-bullets.tp-bullets .tp-bullet.selected,
	.factoryplus-bullets.tp-bullets .tp-bullet:hover {border-color: $colors}

	.fh_button:hover, .tp-caption.fh_button:hover,
	.gh-accordion.vc_tta-accordion .vc_tta-panel.vc_active .vc_tta-panel-heading,
	.gh-accordion.vc_tta-accordion .vc_tta-panel.vc_active .vc_tta-panel-body {border-color: $colors !important}

	.fh-history .owl-nav .owl-prev:hover:after,
	.nav ul ul,
	.woocommerce span.ribbons:before { border-top-color: $colors }

	.fh-history .owl-nav .owl-prev:hover:after,
	.woocommerce span.ribbons:before { border-left-color: $colors }

	.fh-history .owl-nav .owl-next:hover:after { border-right-color: $colors }

	.fh-history .owl-nav .owl-next:hover:after,
	.fh-testimonials-carousel .feedback-title:after {border-bottom-color: $colors}

	/*Color: */
	.fh-section-title.has-icon .fh-icon i,
	.fh-contact-box .info-item i,
	.fh-project .item-project .project-summary .project-cat,
	.fh-project .item-project .project-summary .project-cat a,
	.fh-project.style-2 ul.filter li.active,.fh-project.style-2 ul.filter li:hover,
	.fh-project.style-3 ul.filter li.active,.fh-project.style-3 ul.filter li:hover,
	.fh-project-meta i,
	.fh-latest-post .blog-link i,
	.fh-latest-post .item-latest-post .entry-footer a:hover,
	.fh-latest-post .item-latest-post:hover h2 a,
	.fh-latest-post.style-2 .blog-link:hover,
	.fh-latest-post.style-2 .blog-link:hover i,
	.fh-latest-post.carousel .item-latest-post .entry-meta .posted-on:before,
	.fh-icon-box.style-2 .fh-icon,
	.fh-icon-box.style-3 i,
	.fh-icon-box-2 i,
	.fh-phone .hotline i,
	.fh-counter .fh-icon,
	.fh-testimonials .testi-star i,
	.fh-testimonials .testi-job,
	.fh-testimonials.style-1 .testi-content:hover i,
	.fh-testimonials.style-2 .testi-content:hover i,
	.fh-testimonials-carousel .feedback-title i,
	.fh-testimonials-carousel .testi-star i,
	.fh-testimonials-carousel .owl-nav div:hover,
	.fh-testimonials-carousel.style-2 .info .testi-job,
	.fh-testimonials-carousel.style-2 .owl-nav div:hover,
	.fh-testimonials-carousel.style-3 .testi-job,
	.fh-testimonials-carousel.style-3 .owl-nav div:hover,
	.fh-testimonials-carousel.style-4 .testi-content:hover i,
	.fh-price-table .table-content a,
	.fh-service-2.style-1 .service-icon,
	.fh-team ul li:hover a,
	.fh-team .job,
	.fh-team.style-1 .socials-1 ul li a:hover,
	.list-service li i,
	.custom-quote blockquote:before,
	.custom-quote blockquote a,
	.fh-icon-box:hover h4, .fh-icon-box:hover h4 a,
	.fh-service .service-content:hover h2,
	.fh-service .service-content:hover h2 a,
	.socials a:hover,
	.main-color,
	.topbar .widget .topbar-contact i,
	.topbar .topbar-socials li:hover a,
	.page-header .breadcrumb-area nav span[itemprop="title"],
	.page-header.style-2 .subtitle,
	.page-header .breadcrumb-area nav i,
	.site-extra-text .item-text a:hover,
	.site-extra-text .item-1 i,
	.site-extra-text .item-2 i,
	.site-extra-text .item-3 i,
	.site-extra-text .header-buttom a,
	.site-extra-text .social a:hover,
	.nav ul.menu > li:hover > a,.nav ul.menu > li.current-menu-item > a,.nav ul.menu > li.current-menu-parent > a,
	.nav div.menu > ul > li.current-menu-item > a,.nav div.menu > ul > li:hover > a,
	.header-v2 .main-nav ul.menu > li:hover > a,.header-v2 .main-nav ul.menu > li.current-menu-item > a,.header-v2 .main-nav ul.menu > li.current-menu-parent > a,
	.header-v3.header-transparent .menu-item-text i,
	.header-v4 .main-nav ul.menu > li:hover > a,.header-v4 .main-nav ul.menu > li.current-menu-item > a,.header-v4 .main-nav ul.menu > li.current-menu-parent > a,
	.show-icon .main-nav ul.menu > li:after,
	.post-navigation a:hover,
	.portfolio-navigation .nav-previous a:hover,.portfolio-navigation .nav-next a:hover,
	.project-nav-ajax nav.numeric-navigation .page-numbers.next,
	.project-nav-ajax nav.numeric-navigation .page-numbers.next span,
	.primary-mobile-nav ul.menu li.current-menu-item > a,
	.entry-meta a:hover,
	.entry-meta .meta.views:hover,
	.entry-meta .fa,
	.blog-wrapper .entry-footer a:hover,
	.blog-wrapper:hover h2 a,
	.single-service cite span,
	.project cite span,
	.metas i,
	.project-wrapper .project-summary .project-cat a,
	.backtotop,
	.backtotop .fa,
	.backtotop:hover,
	.backtotop:hover .fa,
	.comment .comment-reply-link:hover,
	.widget_recent_comments li:hover > a,.widget_rss li:hover > a,
	.widget_categories li:hover,.widget_pages li:hover,.widget_archive li:hover,.widget_nav_menu li:hover,.widget_recent_entries li:hover,.widget_meta li:hover,ul.service-menu li:hover,
	.widget_categories li:hover:before,.widget_pages li:hover:before,.widget_archive li:hover:before,.widget_nav_menu li:hover:before,.widget_recent_entries li:hover:before,.widget_meta li:hover:before,ul.service-menu li:hover:before,
	.widget_categories li:hover > a,.widget_pages li:hover > a,.widget_archive li:hover > a,.widget_nav_menu li:hover > a,.widget_recent_entries li:hover > a,.widget_meta li:hover > a,ul.service-menu li:hover > a,
	.widget_categories li:hover > a:before,.widget_pages li:hover > a:before,.widget_archive li:hover > a:before,.widget_nav_menu li:hover > a:before,.widget_recent_entries li:hover > a:before,.widget_meta li:hover > a:before,ul.service-menu li:hover > a:before,
	.popular-posts-widget i,
	.widget-about a:hover,
	.related-post .post-text .post-date i,.popular-post .post-text .post-date i,
	.service-sidebar .side-contact i,
	.woocommerce .star-rating span:before,
	.woocommerce div.product div.summary p.price > span,
	.woocommerce div.product div.summary p.price ins,
	.woocommerce div.product .woocommerce-tabs ul.tabs li.active a,.woocommerce div.product .woocommerce-tabs ul.tabs li:hover a,
	.woocommerce #reviews #review_form .comment-form .comment-form-rating .stars a,
	.woocommerce .quantity .increase:hover,.woocommerce .quantity .decrease:hover,
	.woocommerce ul.products li.product .price > span,
	.woocommerce ul.products li.product .price ins,
	.woocommerce form.checkout table.shop_table td span.amount,
	.woocommerce table.shop_table td.product-subtotal,
	.woocommerce .widget_product_categories li:hover,
	.woocommerce .widget_product_categories li:hover a,
	.woocommerce .widget_product_categories li:hover a:before,
	.woocommerce ul.product_list_widget li > span.amount,
	.woocommerce ul.product_list_widget li ins,
	.woocommerce-wishlist table.shop_table tr td.product-stock-status span.wishlist-in-stock,
	.woocommerce-wishlist table.shop_table tbody .product-price > span,
	.woocommerce-wishlist table.shop_table tbody .product-price ins,
	.woocommerce-account form.login a.lost-password,.woocommerce-account form.register a.lost-password,
	.woocommerce-account .woocommerce-MyAccount-navigation ul li:hover a,.woocommerce-account .woocommerce-MyAccount-navigation ul li.is-active a,
	.woocommerce-cart a.remove:hover i,
	.woocommerce-checkout .woocommerce-info a,
	.site-footer .footer-copyright a,
	.footer-widgets .menu li a:before,
	.footer-widgets .menu li:hover a,
	.footer-widgets .footer-widget-socials li:hover a,
	.latest-post .post-date,
	.footer-social a:hover,
	.footer-contact .ft-contact i,
	.fh-team div.team-member ul li a
	.factoryplus-arrow:hover .fa,
	.service:hover .service-title a,
	.footer-menu ul li a:hover,
	.gardenhub-social-links-widget a:hover {color: $colors}

	.gh-accordion.style-2.vc_tta-accordion .vc_tta-panel-title a i {color: $colors !important}

CSS;
}

if ( ! function_exists( 'gardenhub_typography_css' ) ) :
	/**
	 * Get typography CSS base on settings
	 *
	 * @since 1.1.6
	 */
	function gardenhub_typography_css() {
		$css        = '';
		$properties = array(
			'font-family'    => 'font-family',
			'font-size'      => 'font-size',
			'variant'        => 'font-weight',
			'line-height'    => 'line-height',
			'letter-spacing' => 'letter-spacing',
			'color'          => 'color',
			'text-transform' => 'text-transform',
			'text-align'     => 'text-align',
		);

		$settings = array(
			'body_typo'        => 'body',
			'heading1_typo'    => 'h1',
			'heading2_typo'    => 'h2',
			'heading3_typo'    => 'h3',
			'heading4_typo'    => 'h4',
			'heading5_typo'    => 'h5',
			'heading6_typo'    => 'h6',
			'menu_typo'        => '.nav a, .menu-item-text',
			'footer_text_typo' => '.site-footer',
		);

		foreach ( $settings as $setting => $selector ) {
			$typography = gardenhub_get_option( $setting );
			$default    = (array) gardenhub_get_option_default( $setting );
			$style      = '';

			foreach ( $properties as $key => $property ) {
				if ( isset( $typography[$key] ) && ! empty( $typography[$key] ) ) {
					if ( isset( $default[$key] ) && strtoupper( $default[$key] ) == strtoupper( $typography[$key] ) ) {
						continue;
					}

					$value = 'font-family' == $key ? '"' . rtrim( trim( $typography[$key] ), ',' ) . '"' : $typography[$key];
					$value = 'variant' == $key ? str_replace( 'regular', '400', $value ) : $value;

					if ( $value ) {
						$style .= $property . ': ' . $value . ';';
					}
				}
			}

			if ( ! empty( $style ) ) {
				$css .= $selector . '{' . $style . '}';
			}
		}

		return $css;
	}
endif;

/**
 * Returns CSS for the typography.
 *
 * @return string typography CSS.
 */
function gardenhub_get_heading_typography_css() {

	$headings   = array(
		'h1' => 'heading1_typo',
		'h2' => 'heading2_typo',
		'h3' => 'heading3_typo',
		'h4' => 'heading4_typo',
		'h5' => 'heading5_typo',
		'h6' => 'heading6_typo'
	);
	$inline_css = '';
	foreach ( $headings as $heading ) {
		$keys = array_keys( $headings, $heading );
		if ( $keys ) {
			$inline_css .= gardenhub_get_heading_font( $keys[0], $heading );
		}
	}


	return $inline_css;

}

/**
 * Returns CSS for the typography.
 *
 *
 * @param array $body_typo Color scheme body typography.
 *
 * @return string typography CSS.
 */
function gardenhub_get_heading_font( $key, $heading ) {

	$inline_css   = '';
	$heading_typo = gardenhub_get_option( $heading );

	if ( $heading_typo ) {
		if ( isset( $heading_typo['font-family'] ) && strtolower( $heading_typo['font-family'] ) !== 'roboto' ) {
			$inline_css .= $key . '{font-family:' . rtrim( trim( $heading_typo['font-family'] ), ',' ) . ', Arial, sans-serif}';
		}
	}

	if ( empty( $inline_css ) ) {
		return;
	}

	return <<<CSS
	{$inline_css}
CSS;
}