<?php
/**
 * Hooks for frontend display
 *
 * @package Gardenhub
 */


/**
 * Adds custom classes to the array of body classes.
 *
 * @since 1.0
 * @param array $classes Classes for the body element.
 * @return array
 */
function gardenhub_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Add a class of layout style
	$classes[] = gardenhub_get_option( 'layout_style' );

	// Add a class of layout
	$classes[] = gardenhub_get_layout();

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	if ( in_array( gardenhub_get_option( 'header_layout' ), array( 'v3' ) ) && is_page_template( 'template-homepage.php' ) ) {
		$classes[] = 'header-transparent';
	}

	if ( is_post_type_archive( 'project' ) || is_tax( 'project_category' ) ) {

		if ( 'ajax' == gardenhub_get_option( 'project_nav_type' ) ) {
			$classes[] = 'project-nav-ajax';
		}

		if ( false != gardenhub_get_option( 'project_view' ) ) {
			$classes[] = 'project-grid-fullwidth';
		}
	}

	if ( gardenhub_get_option( 'header_sticky' ) ) {
		$classes[] = 'header-sticky';
	}

	if ( gardenhub_get_option( 'topbar_mobile' ) ) {
		$classes[] = 'hide-topbar-mobile';
	}

	if ( gardenhub_get_option( 'hover_effect') == 1 ) {
		$classes[] = 'show-icon';
	}

	$classes[] = 'blog-' . gardenhub_get_option( 'blog_layout' );

	$classes[] = 'header-' . gardenhub_get_option( 'header_layout' );

	return $classes;
}
add_filter( 'body_class', 'gardenhub_body_classes' );


if ( ! function_exists( 'gardenhub_get_layout' ) ) :
	/**
	 * Get layout base on current page
	 *
	 * @return string
	 */
	function gardenhub_get_layout() {
		$layout = gardenhub_get_option( 'layout_default' );

		if ( is_singular() && get_post_meta( get_the_ID(), 'custom_layout', true ) ) {
			$layout = get_post_meta( get_the_ID(), 'layout', true );
		} elseif ( is_page() ) {
			$layout = gardenhub_get_option( 'layout_page' );
		} elseif ( function_exists( 'is_woocommerce' ) && is_woocommerce() ) {
			$layout = gardenhub_get_option( 'layout_shop' );
		} elseif ( is_404() ) {
			$layout = 'no-sidebar';
		} elseif ( is_post_type_archive( 'project' ) || is_tax( 'project_category' ) || is_singular( 'project' ) ) {
			$layout = gardenhub_get_option( 'layout_project' );
		} elseif ( is_post_type_archive( 'service' ) || is_tax( 'service_category' ) ) {
			$layout = gardenhub_get_option( 'layout_service' );
		} elseif ( is_singular( 'service' ) ) {
			$layout = gardenhub_get_option( 'layout_single_service' );
		}

		return $layout;
	}

endif;

if ( ! function_exists( 'gardenhub_get_content_columns' ) ) :
	/**
	 * Get CSS classes for content columns
	 *
	 * @param string $layout
	 *
	 * @return array
	 */
	function gardenhub_get_content_columns( $layout = null ) {
		$layout = $layout ? $layout : gardenhub_get_layout();

		if ( 'no-sidebar' == $layout ) {
			return array( 'col-md-12' );
		}

		return array( 'col-md-9', 'col-sm-12', 'col-xs-12' );
	}

endif;


if ( ! function_exists( 'gardenhub_content_columns' ) ) :

	/**
	 * Display CSS classes for content columns
	 *
	 * @param string $layout
	 */
	function gardenhub_content_columns( $layout = null ) {
		echo implode( ' ', gardenhub_get_content_columns( $layout ) );
	}

endif;
