<?php
/**
 * Custom functions for nav menu
 *
 * @package GardenHub
 */


/**
 * Display numeric pagination
 *
 * @since 1.0
 * @return void
 */
function gardenhub_numeric_pagination() {
	global $wp_query;

	if( $wp_query->max_num_pages < 2 ) {
        return;
	}

	?>
	<nav class="navigation paging-navigation numeric-navigation">
		<?php
		$big = 999999999;
		$args = array(
			'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'total'     => $wp_query->max_num_pages,
			'current'   => max( 1, get_query_var( 'paged' ) ),
			'prev_text' => '<i class="fa fa-caret-left" aria-hidden="true"></i>',
			'next_text' => '<i class="fa fa-caret-right" aria-hidden="true"></i>',
			'type'      => 'plain',
		);

		if ( is_post_type_archive( 'project' ) && 'ajax' == gardenhub_get_option( 'project_nav_type' ) ) :
			$args['prev_text'] = '';
			$args['next_text'] = sprintf( '<span class="load-more">%s</span><span class="gardenhub-loading">%s</span>', esc_html__( 'Load More', 'gardenhub' ),esc_html__( 'Loading', 'gardenhub' ) );
		endif;

		echo paginate_links( $args );
		?>
	</nav>
<?php
}

/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since 1.0
 * @return void
 */
function gardenhub_paging_nav() {
	// Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}
	?>
	<nav class="navigation paging-navigation">
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
				<div class="nav-previous"><?php next_posts_link( wp_kses_post( esc_html__( '<span class="meta-nav">&larr;</span> Older posts', 'gardenhub' ) ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
				<div class="nav-next"><?php previous_posts_link( wp_kses_post( esc_html__( 'Newer posts <span class="meta-nav">&rarr;</span>', 'gardenhub' ) ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
<?php
}

function gardenhub_portfolio_nav( $post_tyle ) {
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}
	?>
	<nav class="navigation portfolio-navigation" >
		<div class="container">
			<div class="nav-links">
				<?php
				previous_post_link( '<div class="nav-previous">%link</div>', esc_html__( 'Prev', 'gardenhub' ) );
				?>
				<a class="portfolio-link" href="<?php echo esc_url( get_post_type_archive_link( $post_tyle ) ) ?>"><i class="fa fa-th"></i></a>
				<?php
				next_post_link( '<div class="nav-next">%link</div>', esc_html__( 'Next', 'gardenhub' ) );
				?>
			</div><!-- .nav-links -->
		</div>
	</nav><!-- .navigation -->
	<?php
}

/**
 * Display navigation to next/previous post when applicable.
 *
 * @since 1.0
 * @return void
 */
function gardenhub_post_nav() {
	the_post_navigation(
		array(
			'prev_text' => '<span class="screen-reader-text">' . esc_html__( 'Previous Post', 'gardenhub' ) . '</span><span class="meta-nav"><i class="fa fa-chevron-left"></i></span><span aria-hidden="true" class="nav-subtitle">' . esc_html__( 'Prev', 'gardenhub' ) . '</span>',
			'next_text' => '<span class="screen-reader-text">' . esc_html__( 'Next Post', 'gardenhub' ) . '</span><span aria-hidden="true" class="nav-subtitle">' . esc_html__( 'Next', 'gardenhub' ) . '</span><span class="meta-nav"><i class="fa fa-chevron-right"></i></span>',
		)
	);
}